Rem This module takes care of input and output of parameters
Rem    from the file wprairie.ini
Rem    this routine is called at the very beginning of the program, so
Rem    all defaults should be set here
Rem changed IniFileName to global variable 4/28/96

Option Explicit
Option Compare Text

Global IniFileName As String

' User Profile Routines

' Next 3 refer to private.ini (in windows directory unless explicit path given)
Declare Function GetPrivateProfileInt Lib "Kernel" (ByVal lpApplicationName As String, ByVal lpKeyName As String, ByVal nDefault As Integer, ByVal lpFileName As String) As Integer
Declare Function GetPrivateProfileString Lib "Kernel" (ByVal lpApplicationName As String, ByVal lpKeyName As String, ByVal lpDefault As String, ByVal lpReturnedString As String, ByVal nSize As Integer, ByVal lpFileName As String) As Integer
Declare Function WritePrivateProfileString Lib "Kernel" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpString As String, ByVal lplFileName As String) As Integer

Function CheckFloatFormat (ByVal NumberString As String) As Double
Rem Check a string for proper floating point format - if it contains
Rem   a comma, replace it with a period
Rem Does not modify the original string - passed 'ByVal'
If InStr(NumberString, ",") > 0 Then
    Mid$(NumberString, InStr(NumberString, ","), 1) = "."
End If
CheckFloatFormat = Val(NumberString)

End Function

Function GetFloatingPref (Group As String, Item As String, Default As String) As Double
Rem Get a "Preference" setting from the .ini file as a string
Rem  Trims anything after the null

Dim ErrCode As Integer, ProfileString As String * 64

    ErrCode = GetPrivateProfileString(Group, Item, Default, ProfileString, 64, IniFileName)
    GetFloatingPref = CheckFloatFormat(Left$(ProfileString, InStr(ProfileString, Chr$(0)) - 1))

End Function

Function GetIntegerPref (Group As String, Item As String, Default As String) As Long
Rem Get a "Preference" setting from the .ini file as a string
Rem  Trims anything after the null

Dim ErrCode As Integer, ProfileString As String * 64

    ErrCode = GetPrivateProfileString(Group, Item, Default, ProfileString, 64, IniFileName)
    GetIntegerPref = Val(Left$(ProfileString, InStr(ProfileString, Chr$(0)) - 1))

End Function

Function GetLogicalPref (Group As String, Item As String, Default As Integer) As Integer
Rem Get a "Preference" setting from the .ini file as a string
Rem  Parses the file for "true" or "false" and returns result

Dim ErrCode As Integer, ProfileString As String * 32

    If Default Then
        ErrCode = GetPrivateProfileString(Group, Item, "true", ProfileString, 32, IniFileName)
    Else
        ErrCode = GetPrivateProfileString(Group, Item, "false", ProfileString, 32, IniFileName)
    End If
    If InStr((Left$(ProfileString, InStr(ProfileString, Chr$(0)) - 1)), "true") Then
        GetLogicalPref = True
    Else
        GetLogicalPref = False
    End If

End Function

Sub GetSettings ()
Dim Temp As String
Dim I As Integer, MenuIndex As Integer

Rem Read settings from .ini file

Rem Initialize the positions of the forms

    Rem Main form - always loaded, no shadowing needed
    frmControl.Top = GetIntegerPref("MainForm", "Top", "0")
    frmControl.Left = GetIntegerPref("MainForm", "Left", "0")
    
Rem Options and flags - should probably be shadowed

    NRadios = GetIntegerPref("General", "NumberOfRadios", "2")
    StartupPanel = GetStringPref("General", "StartupPanel", "Radios")

    AzElServerTopic = GetStringPref("AzElServer", "Topic", "")
    AzElServerItem = GetStringPref("AzElServer", "Item", "")

    ShowDiags = GetLogicalPref("General", "ShowDiags", False)
    
    AutoMode = GetLogicalPref("General", "AutoMode", False)

Rem Hardware Settings
Rem Handled in individual module initialization 5/29/96

End Sub

Function GetStringPref (Group As String, Item As String, Default As String) As String
Rem Get a "Preference" setting from the .ini file as a string
Rem  Trims anything after the null, and any leading or trailing spaces

Dim ErrCode As Integer, ProfileString As String * 512

    ErrCode = GetPrivateProfileString(Group, Item, Default, ProfileString, 512, IniFileName)
    GetStringPref = Trim$(Left$(ProfileString, InStr(ProfileString, Chr$(0)) - 1))

End Function

Sub ParseCommaList (InList As String, Array() As String, NVals As Integer)
Rem Parse a comma-delimited list and put the entries in Array

Dim CommaPos As Integer, LeftPart As String', RightPart As String

CommaPos = InStr(InList, ",")
'NVals = -1
NVals = 0
LeftPart = InList

While CommaPos > 0
    ReDim Preserve Array(NVals + 1)
    Array(NVals) = Trim$(Left$(LeftPart, CommaPos - 1))
    LeftPart = Right$(LeftPart, Len(LeftPart) - CommaPos)
    CommaPos = InStr(LeftPart, ",")
    NVals = NVals + 1
Wend
Rem Last item
Array(NVals) = Trim$(LeftPart)

End Sub

Sub SaveSettings ()
Rem Write all options to the WPrairie.ini file

Dim E As Integer, I As Integer, Groupname  As String

Rem General Info
E = WritePrivateProfileString("General", "NumberOfRadios", Str$(NRadios), IniFileName)
E = WritePrivateProfileString("General", "StartupPanel", StartupPanel, IniFileName)
E = WritePrivateProfileString("General", "ShowDiags", TrueFalse(ShowDiags), IniFileName)
E = WritePrivateProfileString("General", "AutoMode", TrueFalse(AutoMode), IniFileName)
E = WritePrivateProfileString("General", "Version", Version(), IniFileName)

Rem Optional alternate Az/El Server
If AzElServerTopic <> "" Then
    E = WritePrivateProfileString("AzElServer", "Topic", AzElServerTopic, IniFileName)
    E = WritePrivateProfileString("AzElServer", "Item", AzElServerItem, IniFileName)
End If

Rem Save Main form info
If frmControl.WindowState <> 1 Then
    E = WritePrivateProfileString("MainForm", "Top", Str$(frmControl.Top), IniFileName)
    E = WritePrivateProfileString("MainForm", "Left", Str$(frmControl.Left), IniFileName)
End If

Rem Save Diag form info
If ShowDiags Then
    E = WritePrivateProfileString("Diags", "Top", Str$(frmDiags.Top), IniFileName)
    E = WritePrivateProfileString("Diags", "Left", Str$(frmDiags.Left), IniFileName)
End If

Rem Prairie Board Info
E = WritePrivateProfileString("PrairieBoard", "BaseAddress", Str$(BaseAddress), IniFileName)

Rem Parallel Port Info
E = WritePrivateProfileString("ParallelPort", "BaseAddress", Str$(ParallelPortAddress), IniFileName)
E = WritePrivateProfileString("ParallelPort", "SetupByte", Str$(SetupByte), IniFileName)
E = WritePrivateProfileString("ParallelPort", "ShutdownByte", Str$(ShutdownByte), IniFileName)
E = WritePrivateProfileString("ParallelPort", "Tune_upbit", Str$(Tune_upbit), IniFileName)
E = WritePrivateProfileString("ParallelPort", "Tune_dnbit", Str$(Tune_dnbit), IniFileName)

Rem Rotors group
E = WritePrivateProfileString("Rotors", "ControlType", AntennaControlType, IniFileName)
E = WritePrivateProfileString("Rotors", "AzEnabled", TrueFalse(Az.Enabled), IniFileName)
E = WritePrivateProfileString("Rotors", "ElEnabled", TrueFalse(El.Enabled), IniFileName)
E = WritePrivateProfileString("Rotors", "ElCCWLimit", Str$(El.CCWLimit), IniFileName)
E = WritePrivateProfileString("Rotors", "ElCWLimit", Str$(El.CWLimit), IniFileName)
E = WritePrivateProfileString("Rotors", "AzCCWLimit", Str$(Az.CCWLimit), IniFileName)
E = WritePrivateProfileString("Rotors", "AzCWLimit", Str$(Az.CWLimit), IniFileName)
'E = WritePrivateProfileString("Rotors", "El_180_OK", TrueFalse(Rotor_El180_OK), IniFileName)
E = WritePrivateProfileString("Rotors", "Deadband", Str$(Az.Deadband), IniFileName)
E = WritePrivateProfileString("Rotors", "MinElevation", Str$(MinElevation), IniFileName)
E = WritePrivateProfileString("Rotors", "StartElevation", Str$(StartElevation), IniFileName)
E = WritePrivateProfileString("Rotors", "CommPort", AntennaCommPort, IniFileName)
E = WritePrivateProfileString("Rotors", "BaudRate", Str$(AntennaBaudRate), IniFileName)

Rem Radio groups
If NRadios = 0 Then Exit Sub
For I = 0 To NRadios - 1
Groupname = "Radio" & Format$(I)
E = WritePrivateProfileString(Groupname, "RadioName", Radio(I).RadioName, IniFileName)
E = WritePrivateProfileString(Groupname, "TuningType", Radio(I).TuningType, IniFileName)
E = WritePrivateProfileString(Groupname, "CompType", Radio(I).CompType, IniFileName)
E = WritePrivateProfileString(Groupname, "TuneStep", Str$(Radio(I).TuneStep), IniFileName)
E = WritePrivateProfileString(Groupname, "DelayMsec", Str$(DelayMsec), IniFileName)
E = WritePrivateProfileString(Groupname, "RigType", Radio(I).RigType, IniFileName)
E = WritePrivateProfileString(Groupname, "CommPort", Radio(I).CommPort, IniFileName)
E = WritePrivateProfileString(Groupname, "BaudRate", Str$(Radio(I).BaudRate), IniFileName)
'E = WritePrivateProfileString(Groupname, "StartupString", Radio(I).StartupString, IniFileName)
'E = WritePrivateProfileString(Groupname, "StartupHexString", Radio(I).StartupHexString, IniFileName)
'E = WritePrivateProfileString(Groupname, "ShutdownString", Radio(I).ShutdownString, IniFileName)
'E = WritePrivateProfileString(Groupname, "ShutdownHexString", Radio(I).ShutdownHexString, IniFileName)
E = WritePrivateProfileString(Groupname, "VFOIndex", Str$(Radio(I).VFOIndex), IniFileName)
E = WritePrivateProfileString(Groupname, "Mode", Radio(I).Mode, IniFileName)
E = WritePrivateProfileString(Groupname, "PowerOnFrequency", Str$(Radio(I).PowerOnFreq), IniFileName)
E = WritePrivateProfileString(Groupname, "InitialFrequency", Str$(Radio(I).InitialFreq), IniFileName)
E = WritePrivateProfileString(Groupname, "LOOffsetFrequency", Str$(Radio(I).LOOffsetFreq), IniFileName)
E = WritePrivateProfileString(Groupname, "BandLimitLower", Str$(Radio(I).BandLimitLower), IniFileName)
E = WritePrivateProfileString(Groupname, "BandLimitUpper", Str$(Radio(I).BandLimitUpper), IniFileName)
Next I

End Sub

Function TrueFalse (FlagVal As Integer) As String

If FlagVal Then
    TrueFalse = "True"
Else
    TrueFalse = "False"
End If

End Function

